# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from ...types.json_object import JsonObject
from ...types.legacy_classification import LegacyClassification
from ...types.legacy_classification_advanced_options import LegacyClassificationAdvancedOptions
from ...types.legacy_classification_config_base_processor import LegacyClassificationConfigBaseProcessor
from ...types.legacy_extraction_advanced_options import LegacyExtractionAdvancedOptions
from ...types.legacy_extraction_config_base_processor import LegacyExtractionConfigBaseProcessor
from ...types.legacy_splitter_advanced_options import LegacySplitterAdvancedOptions
from ...types.legacy_splitter_config_base_processor import LegacySplitterConfigBaseProcessor
from ...types.parse_config import ParseConfig


class ProcessorUpdateRequestConfig_Classify(UncheckedBaseModel):
    """
    The new configuration for the processor. The type of configuration must match the processor type:
    * For classification processors, use `ClassificationConfig`
    * For extraction processors, use `ExtractionConfig`
    * For splitter processors, use `SplitterConfig`
    """

    type: typing.Literal["CLASSIFY"] = "CLASSIFY"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacyClassificationConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    classifications: typing.List[LegacyClassification]
    classification_rules: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="classificationRules")
    ] = pydantic.Field(alias="classificationRules", default=None)
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacyClassificationAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ProcessorUpdateRequestConfig_Extract(UncheckedBaseModel):
    """
    The new configuration for the processor. The type of configuration must match the processor type:
    * For classification processors, use `ClassificationConfig`
    * For extraction processors, use `ExtractionConfig`
    * For splitter processors, use `SplitterConfig`
    """

    type: typing.Literal["EXTRACT"] = "EXTRACT"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    extraction_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="extractionRules")] = (
        pydantic.Field(alias="extractionRules", default=None)
    )
    schema_: typing_extensions.Annotated[typing.Optional[JsonObject], FieldMetadata(alias="schema")] = pydantic.Field(
        alias="schema", default=None
    )
    fields: typing.Optional[typing.List["LegacyExtractionField"]] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class ProcessorUpdateRequestConfig_Splitter(UncheckedBaseModel):
    """
    The new configuration for the processor. The type of configuration must match the processor type:
    * For classification processors, use `ClassificationConfig`
    * For extraction processors, use `ExtractionConfig`
    * For splitter processors, use `SplitterConfig`
    """

    type: typing.Literal["SPLITTER"] = "SPLITTER"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacySplitterConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    split_classifications: typing_extensions.Annotated[
        typing.List[LegacyClassification], FieldMetadata(alias="splitClassifications")
    ] = pydantic.Field(alias="splitClassifications")
    split_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="splitRules")] = pydantic.Field(
        alias="splitRules", default=None
    )
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacySplitterAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


ProcessorUpdateRequestConfig = typing_extensions.Annotated[
    typing.Union[
        ProcessorUpdateRequestConfig_Classify,
        ProcessorUpdateRequestConfig_Extract,
        ProcessorUpdateRequestConfig_Splitter,
    ],
    UnionMetadata(discriminant="type"),
]
from ...types.legacy_extraction_field import LegacyExtractionField  # noqa: E402, I001

update_forward_refs(ProcessorUpdateRequestConfig_Extract, LegacyExtractionField=LegacyExtractionField)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.workflow import Workflow
from .raw_client import AsyncRawWorkflowsClient, RawWorkflowsClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class WorkflowsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawWorkflowsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawWorkflowsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawWorkflowsClient
        """
        return self._raw_client

    def create(self, *, name: str, request_options: typing.Optional[RequestOptions] = None) -> Workflow:
        """
        Create a new workflow in Extend. Workflows are sequences of steps that process files and data in a specific order to achieve a desired outcome.

        This endpoint will create a new workflow in Extend, which can then be configured and deployed. Typically, workflows are created from our UI, however this endpoint can be used to create workflows programmatically. Configuration of the flow still needs to be done in the dashboard.

        Parameters
        ----------
        name : str
            The name of the workflow

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Workflow
            Successfully created workflow

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.workflows.create(
            name="Invoice Processing",
        )
        """
        _response = self._raw_client.create(name=name, request_options=request_options)
        return _response.data


class AsyncWorkflowsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawWorkflowsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawWorkflowsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawWorkflowsClient
        """
        return self._raw_client

    async def create(self, *, name: str, request_options: typing.Optional[RequestOptions] = None) -> Workflow:
        """
        Create a new workflow in Extend. Workflows are sequences of steps that process files and data in a specific order to achieve a desired outcome.

        This endpoint will create a new workflow in Extend, which can then be configured and deployed. Typically, workflows are created from our UI, however this endpoint can be used to create workflows programmatically. Configuration of the flow still needs to be done in the dashboard.

        Parameters
        ----------
        name : str
            The name of the workflow

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        Workflow
            Successfully created workflow

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.workflows.create(
                name="Invoice Processing",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(name=name, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from .. import core
from ..core.api_error import ApiError as core_api_error_ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.forbidden_error import ForbiddenError
from ..errors.internal_server_error import InternalServerError
from ..errors.not_found_error import NotFoundError
from ..errors.payment_required_error import PaymentRequiredError
from ..errors.too_many_requests_error import TooManyRequestsError
from ..errors.unauthorized_error import UnauthorizedError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.api_error import ApiError as types_api_error_ApiError
from ..types.file import File
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.sort_dir import SortDir
from .types.files_delete_response import FilesDeleteResponse
from .types.files_list_response import FilesListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawFilesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def list(
        self,
        *,
        name_contains: typing.Optional[str] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[FilesListResponse]:
        """
        List files.

        Parameters
        ----------
        name_contains : typing.Optional[str]
            Filters files to only include those that contain the given string in the name.

            Example: `"invoice"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FilesListResponse]
            List of files
        """
        _response = self._client_wrapper.httpx_client.request(
            "files",
            method="GET",
            params={
                "nameContains": name_contains,
                "sortDir": sort_dir,
                "nextPageToken": next_page_token,
                "maxPageSize": max_page_size,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FilesListResponse,
                    construct_type(
                        type_=FilesListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def retrieve(
        self,
        id: str,
        *,
        raw_text: typing.Optional[bool] = None,
        markdown: typing.Optional[bool] = None,
        html: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[File]:
        """
        Fetch a file by its ID.

        Parameters
        ----------
        id : str
            ID for the file. It will always start with `"file_"`.

            Example: `"file_Xj8mK2pL9nR4vT7qY5wZ"`

        raw_text : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the raw text content of the file will be included in the response.

        markdown : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the markdown content of the file will be included in the response.

            Only available for files with a type of PDF, IMG, or DOCX files that were auto-converted to PDFs.

        html : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the html content of the file will be included in the response.

            Only available for files with a type of DOCX.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[File]
            Retrieved file
        """
        _response = self._client_wrapper.httpx_client.request(
            f"files/{jsonable_encoder(id)}",
            method="GET",
            params={
                "rawText": raw_text,
                "markdown": markdown,
                "html": html,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    File,
                    construct_type(
                        type_=File,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> HttpResponse[FilesDeleteResponse]:
        """
        Delete a file and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the file to delete.

            Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[FilesDeleteResponse]
            Successfully deleted file
        """
        _response = self._client_wrapper.httpx_client.request(
            f"files/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FilesDeleteResponse,
                    construct_type(
                        type_=FilesDeleteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    def upload(self, *, file: core.File, request_options: typing.Optional[RequestOptions] = None) -> HttpResponse[File]:
        """
        Upload and create a new file in Extend.

        This endpoint accepts file contents and registers them as a File in Extend, which can be used for [running workflows](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/workflow/run-workflow), [creating evaluation set items](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/evaluation/bulk-create-evaluation-set-items), [parsing](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/parse/parse-file), etc.

        If an uploaded file is detected as a Word or PowerPoint document, it will be automatically converted to a PDF.

        Supported file types can be found [here](https://docs.extend.ai/2026-02-09/product/general/supported-file-types).

        This endpoint requires multipart form encoding. Most HTTP clients will handle this encoding automatically (see the examples).

        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[File]
            Successfully uploaded file
        """
        _response = self._client_wrapper.httpx_client.request(
            "files/upload",
            method="POST",
            data={},
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    File,
                    construct_type(
                        type_=File,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )


class AsyncRawFilesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def list(
        self,
        *,
        name_contains: typing.Optional[str] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[FilesListResponse]:
        """
        List files.

        Parameters
        ----------
        name_contains : typing.Optional[str]
            Filters files to only include those that contain the given string in the name.

            Example: `"invoice"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FilesListResponse]
            List of files
        """
        _response = await self._client_wrapper.httpx_client.request(
            "files",
            method="GET",
            params={
                "nameContains": name_contains,
                "sortDir": sort_dir,
                "nextPageToken": next_page_token,
                "maxPageSize": max_page_size,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FilesListResponse,
                    construct_type(
                        type_=FilesListResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def retrieve(
        self,
        id: str,
        *,
        raw_text: typing.Optional[bool] = None,
        markdown: typing.Optional[bool] = None,
        html: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[File]:
        """
        Fetch a file by its ID.

        Parameters
        ----------
        id : str
            ID for the file. It will always start with `"file_"`.

            Example: `"file_Xj8mK2pL9nR4vT7qY5wZ"`

        raw_text : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the raw text content of the file will be included in the response.

        markdown : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the markdown content of the file will be included in the response.

            Only available for files with a type of PDF, IMG, or DOCX files that were auto-converted to PDFs.

        html : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the html content of the file will be included in the response.

            Only available for files with a type of DOCX.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[File]
            Retrieved file
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"files/{jsonable_encoder(id)}",
            method="GET",
            params={
                "rawText": raw_text,
                "markdown": markdown,
                "html": html,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    File,
                    construct_type(
                        type_=File,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[FilesDeleteResponse]:
        """
        Delete a file and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the file to delete.

            Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[FilesDeleteResponse]
            Successfully deleted file
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"files/{jsonable_encoder(id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    FilesDeleteResponse,
                    construct_type(
                        type_=FilesDeleteResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )

    async def upload(
        self, *, file: core.File, request_options: typing.Optional[RequestOptions] = None
    ) -> AsyncHttpResponse[File]:
        """
        Upload and create a new file in Extend.

        This endpoint accepts file contents and registers them as a File in Extend, which can be used for [running workflows](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/workflow/run-workflow), [creating evaluation set items](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/evaluation/bulk-create-evaluation-set-items), [parsing](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/parse/parse-file), etc.

        If an uploaded file is detected as a Word or PowerPoint document, it will be automatically converted to a PDF.

        Supported file types can be found [here](https://docs.extend.ai/2026-02-09/product/general/supported-file-types).

        This endpoint requires multipart form encoding. Most HTTP clients will handle this encoding automatically (see the examples).

        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[File]
            Successfully uploaded file
        """
        _response = await self._client_wrapper.httpx_client.request(
            "files/upload",
            method="POST",
            data={},
            files={
                "file": file,
            },
            request_options=request_options,
            omit=OMIT,
            force_multipart=True,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    File,
                    construct_type(
                        type_=File,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 402:
                raise PaymentRequiredError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        types_api_error_ApiError,
                        construct_type(
                            type_=types_api_error_ApiError,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise core_api_error_ApiError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.text
            )
        raise core_api_error_ApiError(
            status_code=_response.status_code, headers=dict(_response.headers), body=_response_json
        )



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import httpx
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.request_options import RequestOptions
from .environment import ExtendEnvironment
from .raw_client import AsyncRawExtend, RawExtend
from .requests.classify_config import ClassifyConfigParams
from .requests.classify_request_classifier import ClassifyRequestClassifierParams
from .requests.classify_request_file import ClassifyRequestFileParams
from .requests.edit_config import EditConfigParams
from .requests.edit_request_file import EditRequestFileParams
from .requests.extract_config_json import ExtractConfigJsonParams
from .requests.extract_request_extractor import ExtractRequestExtractorParams
from .requests.extract_request_file import ExtractRequestFileParams
from .requests.parse_config import ParseConfigParams
from .requests.parse_request_file import ParseRequestFileParams
from .requests.split_config import SplitConfigParams
from .requests.split_request_file import SplitRequestFileParams
from .requests.split_request_splitter import SplitRequestSplitterParams
from .types.classify_run import ClassifyRun
from .types.edit_run import EditRun
from .types.extract_run import ExtractRun
from .types.parse_request_response_type import ParseRequestResponseType
from .types.parse_run import ParseRun
from .types.run_metadata import RunMetadata
from .types.split_run import SplitRun

if typing.TYPE_CHECKING:
    from .batch_processor_run.client import AsyncBatchProcessorRunClient, BatchProcessorRunClient
    from .classifier_versions.client import AsyncClassifierVersionsClient, ClassifierVersionsClient
    from .classifiers.client import AsyncClassifiersClient, ClassifiersClient
    from .classify_runs.client import AsyncClassifyRunsClient, ClassifyRunsClient
    from .edit_runs.client import AsyncEditRunsClient, EditRunsClient
    from .evaluation_set_items.client import AsyncEvaluationSetItemsClient, EvaluationSetItemsClient
    from .evaluation_set_runs.client import AsyncEvaluationSetRunsClient, EvaluationSetRunsClient
    from .evaluation_sets.client import AsyncEvaluationSetsClient, EvaluationSetsClient
    from .extract_runs.client import AsyncExtractRunsClient, ExtractRunsClient
    from .extractor_versions.client import AsyncExtractorVersionsClient, ExtractorVersionsClient
    from .extractors.client import AsyncExtractorsClient, ExtractorsClient
    from .files.client import AsyncFilesClient, FilesClient
    from .parse_runs.client import AsyncParseRunsClient, ParseRunsClient
    from .processor.client import AsyncProcessorClient, ProcessorClient
    from .processor_run.client import AsyncProcessorRunClient, ProcessorRunClient
    from .processor_version.client import AsyncProcessorVersionClient, ProcessorVersionClient
    from .split_runs.client import AsyncSplitRunsClient, SplitRunsClient
    from .splitter_versions.client import AsyncSplitterVersionsClient, SplitterVersionsClient
    from .splitters.client import AsyncSplittersClient, SplittersClient
    from .workflow_runs.client import AsyncWorkflowRunsClient, WorkflowRunsClient
    from .workflows.client import AsyncWorkflowsClient, WorkflowsClient
# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class Extend:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ExtendEnvironment
        The environment to use for requests from the client. from .environment import ExtendEnvironment



        Defaults to ExtendEnvironment.PRODUCTION



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 300 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    extend_api_version : typing.Optional[str]
    Examples
    --------
    from extend_ai import Extend

    client = Extend(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ExtendEnvironment = ExtendEnvironment.PRODUCTION,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
        extend_api_version: typing.Optional[str] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 300 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            extend_api_version=extend_api_version,
        )
        self._raw_client = RawExtend(client_wrapper=self._client_wrapper)
        self._files: typing.Optional[FilesClient] = None
        self._parse_runs: typing.Optional[ParseRunsClient] = None
        self._edit_runs: typing.Optional[EditRunsClient] = None
        self._extract_runs: typing.Optional[ExtractRunsClient] = None
        self._extractors: typing.Optional[ExtractorsClient] = None
        self._extractor_versions: typing.Optional[ExtractorVersionsClient] = None
        self._classify_runs: typing.Optional[ClassifyRunsClient] = None
        self._classifiers: typing.Optional[ClassifiersClient] = None
        self._classifier_versions: typing.Optional[ClassifierVersionsClient] = None
        self._split_runs: typing.Optional[SplitRunsClient] = None
        self._splitters: typing.Optional[SplittersClient] = None
        self._splitter_versions: typing.Optional[SplitterVersionsClient] = None
        self._workflows: typing.Optional[WorkflowsClient] = None
        self._workflow_runs: typing.Optional[WorkflowRunsClient] = None
        self._processor_run: typing.Optional[ProcessorRunClient] = None
        self._processor: typing.Optional[ProcessorClient] = None
        self._processor_version: typing.Optional[ProcessorVersionClient] = None
        self._batch_processor_run: typing.Optional[BatchProcessorRunClient] = None
        self._evaluation_sets: typing.Optional[EvaluationSetsClient] = None
        self._evaluation_set_items: typing.Optional[EvaluationSetItemsClient] = None
        self._evaluation_set_runs: typing.Optional[EvaluationSetRunsClient] = None

    @property
    def with_raw_response(self) -> RawExtend:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawExtend
        """
        return self._raw_client

    def parse(
        self,
        *,
        file: ParseRequestFileParams,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParseRun:
        """
        Parse a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /parse_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](https://docs.extend.ai/2026-02-09/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFileParams
            The file to be parsed. Files can be provided as a URL or an Extend file ID.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfigParams]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParseRun
            Successfully parsed file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.parse(
            file={"url": "url"},
        )
        """
        _response = self._raw_client.parse(
            file=file, response_type=response_type, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    def edit(
        self,
        *,
        file: EditRequestFileParams,
        config: typing.Optional[EditConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditRun:
        """
        Edit a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /edit_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Edit endpoint allows you to detect and fill form fields in PDF documents.

        For more details, see the [Edit File guide](https://docs.extend.ai/2026-02-09/product/editing/edit).

        Parameters
        ----------
        file : EditRequestFileParams
            The file to be edited. Files can be provided as a URL or an Extend file ID.

        config : typing.Optional[EditConfigParams]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditRun
            Successfully edited file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.edit(
            file={"url": "url"},
        )
        """
        _response = self._raw_client.edit(file=file, config=config, request_options=request_options)
        return _response.data

    def extract(
        self,
        *,
        file: ExtractRequestFileParams,
        extractor: typing.Optional[ExtractRequestExtractorParams] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtractRun:
        """
        Extract structured data from a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /extract_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Extract endpoint allows you to extract structured data from files using an existing extractor or an inline configuration.

        For more details, see the [Extract File guide](https://docs.extend.ai/2026-02-09/product/extracting/extract).

        Parameters
        ----------
        file : ExtractRequestFileParams
            The file to be extracted from. Files can be provided as a URL, Extend file ID, or raw text.

        extractor : typing.Optional[ExtractRequestExtractorParams]
            Reference to an existing extractor. One of `extractor` or `config` must be provided.

        config : typing.Optional[ExtractConfigJsonParams]
            Inline extract configuration. One of `extractor` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractRun
            Successfully extracted data from file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.extract(
            file={"url": "url"},
        )
        """
        _response = self._raw_client.extract(
            file=file, extractor=extractor, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    def classify(
        self,
        *,
        file: ClassifyRequestFileParams,
        classifier: typing.Optional[ClassifyRequestClassifierParams] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifyRun:
        """
        Classify a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /classify_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Classify endpoint allows you to classify documents using an existing classifier or an inline configuration.

        For more details, see the [Classify File guide](https://docs.extend.ai/2026-02-09/product/classifying/classify).

        Parameters
        ----------
        file : ClassifyRequestFileParams
            The file to be classified. Files can be provided as a URL, an Extend file ID, or raw text.

        classifier : typing.Optional[ClassifyRequestClassifierParams]
            Reference to an existing classifier. One of `classifier` or `config` must be provided.

        config : typing.Optional[ClassifyConfigParams]
            Inline classify configuration. One of `classifier` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Successfully classified file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.classify(
            file={"url": "url"},
        )
        """
        _response = self._raw_client.classify(
            file=file, classifier=classifier, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    def split(
        self,
        *,
        file: SplitRequestFileParams,
        splitter: typing.Optional[SplitRequestSplitterParams] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplitRun:
        """
        Split a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /split_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Split endpoint allows you to split documents into multiple parts using an existing splitter or an inline configuration.

        For more details, see the [Split File guide](https://docs.extend.ai/2026-02-09/product/splitting/split).

        Parameters
        ----------
        file : SplitRequestFileParams
            The file to be split. Files can be provided as a URL or an Extend file ID.

        splitter : typing.Optional[SplitRequestSplitterParams]
            Reference to an existing splitter. One of `splitter` or `config` must be provided.

        config : typing.Optional[SplitConfigParams]
            Inline splitter configuration. One of `splitter` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Successfully split file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.split(
            file={"url": "url"},
        )
        """
        _response = self._raw_client.split(
            file=file, splitter=splitter, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    @property
    def files(self):
        if self._files is None:
            from .files.client import FilesClient  # noqa: E402

            self._files = FilesClient(client_wrapper=self._client_wrapper)
        return self._files

    @property
    def parse_runs(self):
        if self._parse_runs is None:
            from .parse_runs.client import ParseRunsClient  # noqa: E402

            self._parse_runs = ParseRunsClient(client_wrapper=self._client_wrapper)
        return self._parse_runs

    @property
    def edit_runs(self):
        if self._edit_runs is None:
            from .edit_runs.client import EditRunsClient  # noqa: E402

            self._edit_runs = EditRunsClient(client_wrapper=self._client_wrapper)
        return self._edit_runs

    @property
    def extract_runs(self):
        if self._extract_runs is None:
            from .extract_runs.client import ExtractRunsClient  # noqa: E402

            self._extract_runs = ExtractRunsClient(client_wrapper=self._client_wrapper)
        return self._extract_runs

    @property
    def extractors(self):
        if self._extractors is None:
            from .extractors.client import ExtractorsClient  # noqa: E402

            self._extractors = ExtractorsClient(client_wrapper=self._client_wrapper)
        return self._extractors

    @property
    def extractor_versions(self):
        if self._extractor_versions is None:
            from .extractor_versions.client import ExtractorVersionsClient  # noqa: E402

            self._extractor_versions = ExtractorVersionsClient(client_wrapper=self._client_wrapper)
        return self._extractor_versions

    @property
    def classify_runs(self):
        if self._classify_runs is None:
            from .classify_runs.client import ClassifyRunsClient  # noqa: E402

            self._classify_runs = ClassifyRunsClient(client_wrapper=self._client_wrapper)
        return self._classify_runs

    @property
    def classifiers(self):
        if self._classifiers is None:
            from .classifiers.client import ClassifiersClient  # noqa: E402

            self._classifiers = ClassifiersClient(client_wrapper=self._client_wrapper)
        return self._classifiers

    @property
    def classifier_versions(self):
        if self._classifier_versions is None:
            from .classifier_versions.client import ClassifierVersionsClient  # noqa: E402

            self._classifier_versions = ClassifierVersionsClient(client_wrapper=self._client_wrapper)
        return self._classifier_versions

    @property
    def split_runs(self):
        if self._split_runs is None:
            from .split_runs.client import SplitRunsClient  # noqa: E402

            self._split_runs = SplitRunsClient(client_wrapper=self._client_wrapper)
        return self._split_runs

    @property
    def splitters(self):
        if self._splitters is None:
            from .splitters.client import SplittersClient  # noqa: E402

            self._splitters = SplittersClient(client_wrapper=self._client_wrapper)
        return self._splitters

    @property
    def splitter_versions(self):
        if self._splitter_versions is None:
            from .splitter_versions.client import SplitterVersionsClient  # noqa: E402

            self._splitter_versions = SplitterVersionsClient(client_wrapper=self._client_wrapper)
        return self._splitter_versions

    @property
    def workflows(self):
        if self._workflows is None:
            from .workflows.client import WorkflowsClient  # noqa: E402

            self._workflows = WorkflowsClient(client_wrapper=self._client_wrapper)
        return self._workflows

    @property
    def workflow_runs(self):
        if self._workflow_runs is None:
            from .workflow_runs.client import WorkflowRunsClient  # noqa: E402

            self._workflow_runs = WorkflowRunsClient(client_wrapper=self._client_wrapper)
        return self._workflow_runs

    @property
    def processor_run(self):
        if self._processor_run is None:
            from .processor_run.client import ProcessorRunClient  # noqa: E402

            self._processor_run = ProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._processor_run

    @property
    def processor(self):
        if self._processor is None:
            from .processor.client import ProcessorClient  # noqa: E402

            self._processor = ProcessorClient(client_wrapper=self._client_wrapper)
        return self._processor

    @property
    def processor_version(self):
        if self._processor_version is None:
            from .processor_version.client import ProcessorVersionClient  # noqa: E402

            self._processor_version = ProcessorVersionClient(client_wrapper=self._client_wrapper)
        return self._processor_version

    @property
    def batch_processor_run(self):
        if self._batch_processor_run is None:
            from .batch_processor_run.client import BatchProcessorRunClient  # noqa: E402

            self._batch_processor_run = BatchProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._batch_processor_run

    @property
    def evaluation_sets(self):
        if self._evaluation_sets is None:
            from .evaluation_sets.client import EvaluationSetsClient  # noqa: E402

            self._evaluation_sets = EvaluationSetsClient(client_wrapper=self._client_wrapper)
        return self._evaluation_sets

    @property
    def evaluation_set_items(self):
        if self._evaluation_set_items is None:
            from .evaluation_set_items.client import EvaluationSetItemsClient  # noqa: E402

            self._evaluation_set_items = EvaluationSetItemsClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set_items

    @property
    def evaluation_set_runs(self):
        if self._evaluation_set_runs is None:
            from .evaluation_set_runs.client import EvaluationSetRunsClient  # noqa: E402

            self._evaluation_set_runs = EvaluationSetRunsClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set_runs


class AsyncExtend:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : ExtendEnvironment
        The environment to use for requests from the client. from .environment import ExtendEnvironment



        Defaults to ExtendEnvironment.PRODUCTION



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 300 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    extend_api_version : typing.Optional[str]
    Examples
    --------
    from extend_ai import AsyncExtend

    client = AsyncExtend(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: ExtendEnvironment = ExtendEnvironment.PRODUCTION,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
        extend_api_version: typing.Optional[str] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 300 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
            extend_api_version=extend_api_version,
        )
        self._raw_client = AsyncRawExtend(client_wrapper=self._client_wrapper)
        self._files: typing.Optional[AsyncFilesClient] = None
        self._parse_runs: typing.Optional[AsyncParseRunsClient] = None
        self._edit_runs: typing.Optional[AsyncEditRunsClient] = None
        self._extract_runs: typing.Optional[AsyncExtractRunsClient] = None
        self._extractors: typing.Optional[AsyncExtractorsClient] = None
        self._extractor_versions: typing.Optional[AsyncExtractorVersionsClient] = None
        self._classify_runs: typing.Optional[AsyncClassifyRunsClient] = None
        self._classifiers: typing.Optional[AsyncClassifiersClient] = None
        self._classifier_versions: typing.Optional[AsyncClassifierVersionsClient] = None
        self._split_runs: typing.Optional[AsyncSplitRunsClient] = None
        self._splitters: typing.Optional[AsyncSplittersClient] = None
        self._splitter_versions: typing.Optional[AsyncSplitterVersionsClient] = None
        self._workflows: typing.Optional[AsyncWorkflowsClient] = None
        self._workflow_runs: typing.Optional[AsyncWorkflowRunsClient] = None
        self._processor_run: typing.Optional[AsyncProcessorRunClient] = None
        self._processor: typing.Optional[AsyncProcessorClient] = None
        self._processor_version: typing.Optional[AsyncProcessorVersionClient] = None
        self._batch_processor_run: typing.Optional[AsyncBatchProcessorRunClient] = None
        self._evaluation_sets: typing.Optional[AsyncEvaluationSetsClient] = None
        self._evaluation_set_items: typing.Optional[AsyncEvaluationSetItemsClient] = None
        self._evaluation_set_runs: typing.Optional[AsyncEvaluationSetRunsClient] = None

    @property
    def with_raw_response(self) -> AsyncRawExtend:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawExtend
        """
        return self._raw_client

    async def parse(
        self,
        *,
        file: ParseRequestFileParams,
        response_type: typing.Optional[ParseRequestResponseType] = None,
        config: typing.Optional[ParseConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ParseRun:
        """
        Parse a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /parse_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Parse endpoint allows you to convert documents into structured, machine-readable formats with fine-grained control over the parsing process. This endpoint is ideal for extracting cleaned document content to be used as context for downstream processing, e.g. RAG pipelines, custom ingestion pipelines, embeddings classification, etc.

        For more details, see the [Parse File guide](https://docs.extend.ai/2026-02-09/product/parsing/parse).

        Parameters
        ----------
        file : ParseRequestFileParams
            The file to be parsed. Files can be provided as a URL or an Extend file ID.

        response_type : typing.Optional[ParseRequestResponseType]
            Controls the format of the response chunks. Defaults to `json` if not specified.
            * `json` - Returns parsed outputs in the response body
            * `url` - Return a presigned URL to the parsed content in the response body

        config : typing.Optional[ParseConfigParams]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ParseRun
            Successfully parsed file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.parse(
                file={"url": "url"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.parse(
            file=file, response_type=response_type, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    async def edit(
        self,
        *,
        file: EditRequestFileParams,
        config: typing.Optional[EditConfigParams] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> EditRun:
        """
        Edit a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /edit_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Edit endpoint allows you to detect and fill form fields in PDF documents.

        For more details, see the [Edit File guide](https://docs.extend.ai/2026-02-09/product/editing/edit).

        Parameters
        ----------
        file : EditRequestFileParams
            The file to be edited. Files can be provided as a URL or an Extend file ID.

        config : typing.Optional[EditConfigParams]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EditRun
            Successfully edited file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.edit(
                file={"url": "url"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.edit(file=file, config=config, request_options=request_options)
        return _response.data

    async def extract(
        self,
        *,
        file: ExtractRequestFileParams,
        extractor: typing.Optional[ExtractRequestExtractorParams] = OMIT,
        config: typing.Optional[ExtractConfigJsonParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ExtractRun:
        """
        Extract structured data from a file synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /extract_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Extract endpoint allows you to extract structured data from files using an existing extractor or an inline configuration.

        For more details, see the [Extract File guide](https://docs.extend.ai/2026-02-09/product/extracting/extract).

        Parameters
        ----------
        file : ExtractRequestFileParams
            The file to be extracted from. Files can be provided as a URL, Extend file ID, or raw text.

        extractor : typing.Optional[ExtractRequestExtractorParams]
            Reference to an existing extractor. One of `extractor` or `config` must be provided.

        config : typing.Optional[ExtractConfigJsonParams]
            Inline extract configuration. One of `extractor` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ExtractRun
            Successfully extracted data from file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.extract(
                file={"url": "url"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.extract(
            file=file, extractor=extractor, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    async def classify(
        self,
        *,
        file: ClassifyRequestFileParams,
        classifier: typing.Optional[ClassifyRequestClassifierParams] = OMIT,
        config: typing.Optional[ClassifyConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ClassifyRun:
        """
        Classify a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /classify_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Classify endpoint allows you to classify documents using an existing classifier or an inline configuration.

        For more details, see the [Classify File guide](https://docs.extend.ai/2026-02-09/product/classifying/classify).

        Parameters
        ----------
        file : ClassifyRequestFileParams
            The file to be classified. Files can be provided as a URL, an Extend file ID, or raw text.

        classifier : typing.Optional[ClassifyRequestClassifierParams]
            Reference to an existing classifier. One of `classifier` or `config` must be provided.

        config : typing.Optional[ClassifyConfigParams]
            Inline classify configuration. One of `classifier` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ClassifyRun
            Successfully classified file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.classify(
                file={"url": "url"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.classify(
            file=file, classifier=classifier, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    async def split(
        self,
        *,
        file: SplitRequestFileParams,
        splitter: typing.Optional[SplitRequestSplitterParams] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplitRun:
        """
        Split a document synchronously, waiting for the result before returning. This endpoint has a **5-minute timeout** — if processing takes longer, the request will fail.

        **Note:** This endpoint is intended for onboarding and testing only. For production workloads, use `POST /split_runs` with webhooks or polling instead, as it provides better reliability for large files and avoids timeout issues.

        The Split endpoint allows you to split documents into multiple parts using an existing splitter or an inline configuration.

        For more details, see the [Split File guide](https://docs.extend.ai/2026-02-09/product/splitting/split).

        Parameters
        ----------
        file : SplitRequestFileParams
            The file to be split. Files can be provided as a URL or an Extend file ID.

        splitter : typing.Optional[SplitRequestSplitterParams]
            Reference to an existing splitter. One of `splitter` or `config` must be provided.

        config : typing.Optional[SplitConfigParams]
            Inline splitter configuration. One of `splitter` or `config` must be provided.

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Successfully split file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.split(
                file={"url": "url"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.split(
            file=file, splitter=splitter, config=config, metadata=metadata, request_options=request_options
        )
        return _response.data

    @property
    def files(self):
        if self._files is None:
            from .files.client import AsyncFilesClient  # noqa: E402

            self._files = AsyncFilesClient(client_wrapper=self._client_wrapper)
        return self._files

    @property
    def parse_runs(self):
        if self._parse_runs is None:
            from .parse_runs.client import AsyncParseRunsClient  # noqa: E402

            self._parse_runs = AsyncParseRunsClient(client_wrapper=self._client_wrapper)
        return self._parse_runs

    @property
    def edit_runs(self):
        if self._edit_runs is None:
            from .edit_runs.client import AsyncEditRunsClient  # noqa: E402

            self._edit_runs = AsyncEditRunsClient(client_wrapper=self._client_wrapper)
        return self._edit_runs

    @property
    def extract_runs(self):
        if self._extract_runs is None:
            from .extract_runs.client import AsyncExtractRunsClient  # noqa: E402

            self._extract_runs = AsyncExtractRunsClient(client_wrapper=self._client_wrapper)
        return self._extract_runs

    @property
    def extractors(self):
        if self._extractors is None:
            from .extractors.client import AsyncExtractorsClient  # noqa: E402

            self._extractors = AsyncExtractorsClient(client_wrapper=self._client_wrapper)
        return self._extractors

    @property
    def extractor_versions(self):
        if self._extractor_versions is None:
            from .extractor_versions.client import AsyncExtractorVersionsClient  # noqa: E402

            self._extractor_versions = AsyncExtractorVersionsClient(client_wrapper=self._client_wrapper)
        return self._extractor_versions

    @property
    def classify_runs(self):
        if self._classify_runs is None:
            from .classify_runs.client import AsyncClassifyRunsClient  # noqa: E402

            self._classify_runs = AsyncClassifyRunsClient(client_wrapper=self._client_wrapper)
        return self._classify_runs

    @property
    def classifiers(self):
        if self._classifiers is None:
            from .classifiers.client import AsyncClassifiersClient  # noqa: E402

            self._classifiers = AsyncClassifiersClient(client_wrapper=self._client_wrapper)
        return self._classifiers

    @property
    def classifier_versions(self):
        if self._classifier_versions is None:
            from .classifier_versions.client import AsyncClassifierVersionsClient  # noqa: E402

            self._classifier_versions = AsyncClassifierVersionsClient(client_wrapper=self._client_wrapper)
        return self._classifier_versions

    @property
    def split_runs(self):
        if self._split_runs is None:
            from .split_runs.client import AsyncSplitRunsClient  # noqa: E402

            self._split_runs = AsyncSplitRunsClient(client_wrapper=self._client_wrapper)
        return self._split_runs

    @property
    def splitters(self):
        if self._splitters is None:
            from .splitters.client import AsyncSplittersClient  # noqa: E402

            self._splitters = AsyncSplittersClient(client_wrapper=self._client_wrapper)
        return self._splitters

    @property
    def splitter_versions(self):
        if self._splitter_versions is None:
            from .splitter_versions.client import AsyncSplitterVersionsClient  # noqa: E402

            self._splitter_versions = AsyncSplitterVersionsClient(client_wrapper=self._client_wrapper)
        return self._splitter_versions

    @property
    def workflows(self):
        if self._workflows is None:
            from .workflows.client import AsyncWorkflowsClient  # noqa: E402

            self._workflows = AsyncWorkflowsClient(client_wrapper=self._client_wrapper)
        return self._workflows

    @property
    def workflow_runs(self):
        if self._workflow_runs is None:
            from .workflow_runs.client import AsyncWorkflowRunsClient  # noqa: E402

            self._workflow_runs = AsyncWorkflowRunsClient(client_wrapper=self._client_wrapper)
        return self._workflow_runs

    @property
    def processor_run(self):
        if self._processor_run is None:
            from .processor_run.client import AsyncProcessorRunClient  # noqa: E402

            self._processor_run = AsyncProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._processor_run

    @property
    def processor(self):
        if self._processor is None:
            from .processor.client import AsyncProcessorClient  # noqa: E402

            self._processor = AsyncProcessorClient(client_wrapper=self._client_wrapper)
        return self._processor

    @property
    def processor_version(self):
        if self._processor_version is None:
            from .processor_version.client import AsyncProcessorVersionClient  # noqa: E402

            self._processor_version = AsyncProcessorVersionClient(client_wrapper=self._client_wrapper)
        return self._processor_version

    @property
    def batch_processor_run(self):
        if self._batch_processor_run is None:
            from .batch_processor_run.client import AsyncBatchProcessorRunClient  # noqa: E402

            self._batch_processor_run = AsyncBatchProcessorRunClient(client_wrapper=self._client_wrapper)
        return self._batch_processor_run

    @property
    def evaluation_sets(self):
        if self._evaluation_sets is None:
            from .evaluation_sets.client import AsyncEvaluationSetsClient  # noqa: E402

            self._evaluation_sets = AsyncEvaluationSetsClient(client_wrapper=self._client_wrapper)
        return self._evaluation_sets

    @property
    def evaluation_set_items(self):
        if self._evaluation_set_items is None:
            from .evaluation_set_items.client import AsyncEvaluationSetItemsClient  # noqa: E402

            self._evaluation_set_items = AsyncEvaluationSetItemsClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set_items

    @property
    def evaluation_set_runs(self):
        if self._evaluation_set_runs is None:
            from .evaluation_set_runs.client import AsyncEvaluationSetRunsClient  # noqa: E402

            self._evaluation_set_runs = AsyncEvaluationSetRunsClient(client_wrapper=self._client_wrapper)
        return self._evaluation_set_runs


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: ExtendEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class FileContentsPagesItem(UncheckedBaseModel):
    page_number: typing_extensions.Annotated[int, FieldMetadata(alias="pageNumber")] = pydantic.Field(
        alias="pageNumber"
    )
    """
    The page number of this page in the document.
    """

    page_height: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="pageHeight")] = (
        pydantic.Field(alias="pageHeight", default=None)
    )
    """
    The height of the page in points. Available for PDF and IMG file types.
    """

    page_width: typing_extensions.Annotated[typing.Optional[float], FieldMetadata(alias="pageWidth")] = pydantic.Field(
        alias="pageWidth", default=None
    )
    """
    The width of the page in points. Available for PDF and IMG file types.
    """

    markdown: typing.Optional[str] = pydantic.Field(default=None)
    """
    Cleaned and structured markdown content of this page. Available for PDF and IMG file types when the `markdown` query parameter is set to true.
    """

    html: typing.Optional[str] = pydantic.Field(default=None)
    """
    HTML content of the page. Available for DOCX file types when the `html` query parameter is set to true.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



"""Resource clients with polling utilities."""

from .classify_runs import AsyncClassifyRunsClient, ClassifyRunsClient
from .edit_runs import AsyncEditRunsClient, EditRunsClient
from .extract_runs import AsyncExtractRunsClient, ExtractRunsClient
from .parse_runs import AsyncParseRunsClient, ParseRunsClient
from .split_runs import AsyncSplitRunsClient, SplitRunsClient
from .workflow_runs import AsyncWorkflowRunsClient, WorkflowRunsClient

__all__ = [
    "ExtractRunsClient",
    "AsyncExtractRunsClient",
    "ClassifyRunsClient",
    "AsyncClassifyRunsClient",
    "SplitRunsClient",
    "AsyncSplitRunsClient",
    "WorkflowRunsClient",
    "AsyncWorkflowRunsClient",
    "EditRunsClient",
    "AsyncEditRunsClient",
    "ParseRunsClient",
    "AsyncParseRunsClient",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .provided_classify_output import ProvidedClassifyOutput
from .provided_extract_output import ProvidedExtractOutput
from .provided_split_output import ProvidedSplitOutput

ProvidedProcessorOutput = typing.Union[ProvidedExtractOutput, ProvidedClassifyOutput, ProvidedSplitOutput]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...core import enum

T_Result = typing.TypeVar("T_Result")


class ProcessorRunListRequestSource(enum.StrEnum):
    ADMIN = "ADMIN"
    BATCH_PROCESSOR_RUN = "BATCH_PROCESSOR_RUN"
    PLAYGROUND = "PLAYGROUND"
    WORKFLOW_CONFIGURATION = "WORKFLOW_CONFIGURATION"
    WORKFLOW_RUN = "WORKFLOW_RUN"
    STUDIO = "STUDIO"
    API = "API"
    _UNKNOWN = "__PROCESSORRUNLISTREQUESTSOURCE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ProcessorRunListRequestSource":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        admin: typing.Callable[[], T_Result],
        batch_processor_run: typing.Callable[[], T_Result],
        playground: typing.Callable[[], T_Result],
        workflow_configuration: typing.Callable[[], T_Result],
        workflow_run: typing.Callable[[], T_Result],
        studio: typing.Callable[[], T_Result],
        api: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ProcessorRunListRequestSource.ADMIN:
            return admin()
        if self is ProcessorRunListRequestSource.BATCH_PROCESSOR_RUN:
            return batch_processor_run()
        if self is ProcessorRunListRequestSource.PLAYGROUND:
            return playground()
        if self is ProcessorRunListRequestSource.WORKFLOW_CONFIGURATION:
            return workflow_configuration()
        if self is ProcessorRunListRequestSource.WORKFLOW_RUN:
            return workflow_run()
        if self is ProcessorRunListRequestSource.STUDIO:
            return studio()
        if self is ProcessorRunListRequestSource.API:
            return api()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

from .. import core
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.file import File
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.sort_dir import SortDir
from .raw_client import AsyncRawFilesClient, RawFilesClient
from .types.files_delete_response import FilesDeleteResponse
from .types.files_list_response import FilesListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class FilesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFilesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFilesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFilesClient
        """
        return self._raw_client

    def list(
        self,
        *,
        name_contains: typing.Optional[str] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FilesListResponse:
        """
        List files.

        Parameters
        ----------
        name_contains : typing.Optional[str]
            Filters files to only include those that contain the given string in the name.

            Example: `"invoice"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FilesListResponse
            List of files

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.files.list(
            next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
        )
        """
        _response = self._raw_client.list(
            name_contains=name_contains,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    def retrieve(
        self,
        id: str,
        *,
        raw_text: typing.Optional[bool] = None,
        markdown: typing.Optional[bool] = None,
        html: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> File:
        """
        Fetch a file by its ID.

        Parameters
        ----------
        id : str
            ID for the file. It will always start with `"file_"`.

            Example: `"file_Xj8mK2pL9nR4vT7qY5wZ"`

        raw_text : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the raw text content of the file will be included in the response.

        markdown : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the markdown content of the file will be included in the response.

            Only available for files with a type of PDF, IMG, or DOCX files that were auto-converted to PDFs.

        html : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the html content of the file will be included in the response.

            Only available for files with a type of DOCX.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        File
            Retrieved file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.files.retrieve(
            id="file_id_here",
        )
        """
        _response = self._raw_client.retrieve(
            id, raw_text=raw_text, markdown=markdown, html=html, request_options=request_options
        )
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> FilesDeleteResponse:
        """
        Delete a file and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the file to delete.

            Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FilesDeleteResponse
            Successfully deleted file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.files.delete(
            id="file_id_here",
        )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data

    def upload(self, *, file: core.File, request_options: typing.Optional[RequestOptions] = None) -> File:
        """
        Upload and create a new file in Extend.

        This endpoint accepts file contents and registers them as a File in Extend, which can be used for [running workflows](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/workflow/run-workflow), [creating evaluation set items](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/evaluation/bulk-create-evaluation-set-items), [parsing](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/parse/parse-file), etc.

        If an uploaded file is detected as a Word or PowerPoint document, it will be automatically converted to a PDF.

        Supported file types can be found [here](https://docs.extend.ai/2026-02-09/product/general/supported-file-types).

        This endpoint requires multipart form encoding. Most HTTP clients will handle this encoding automatically (see the examples).

        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        File
            Successfully uploaded file

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.files.upload()
        """
        _response = self._raw_client.upload(file=file, request_options=request_options)
        return _response.data


class AsyncFilesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFilesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFilesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFilesClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        name_contains: typing.Optional[str] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FilesListResponse:
        """
        List files.

        Parameters
        ----------
        name_contains : typing.Optional[str]
            Filters files to only include those that contain the given string in the name.

            Example: `"invoice"`

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FilesListResponse
            List of files

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.list(
                next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            name_contains=name_contains,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    async def retrieve(
        self,
        id: str,
        *,
        raw_text: typing.Optional[bool] = None,
        markdown: typing.Optional[bool] = None,
        html: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> File:
        """
        Fetch a file by its ID.

        Parameters
        ----------
        id : str
            ID for the file. It will always start with `"file_"`.

            Example: `"file_Xj8mK2pL9nR4vT7qY5wZ"`

        raw_text : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the raw text content of the file will be included in the response.

        markdown : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the markdown content of the file will be included in the response.

            Only available for files with a type of PDF, IMG, or DOCX files that were auto-converted to PDFs.

        html : typing.Optional[bool]
            **Deprecated:** Use `POST /parse_runs` instead to parse file contents.

            If set to true, the html content of the file will be included in the response.

            Only available for files with a type of DOCX.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        File
            Retrieved file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.retrieve(
                id="file_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(
            id, raw_text=raw_text, markdown=markdown, html=html, request_options=request_options
        )
        return _response.data

    async def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> FilesDeleteResponse:
        """
        Delete a file and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the file to delete.

            Example: `"file_xK9mLPqRtN3vS8wF5hB2cQ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FilesDeleteResponse
            Successfully deleted file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.delete(
                id="file_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data

    async def upload(self, *, file: core.File, request_options: typing.Optional[RequestOptions] = None) -> File:
        """
        Upload and create a new file in Extend.

        This endpoint accepts file contents and registers them as a File in Extend, which can be used for [running workflows](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/workflow/run-workflow), [creating evaluation set items](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/evaluation/bulk-create-evaluation-set-items), [parsing](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/parse/parse-file), etc.

        If an uploaded file is detected as a Word or PowerPoint document, it will be automatically converted to a PDF.

        Supported file types can be found [here](https://docs.extend.ai/2026-02-09/product/general/supported-file-types).

        This endpoint requires multipart form encoding. Most HTTP clients will handle this encoding automatically (see the examples).

        Parameters
        ----------
        file : core.File
            See core.File for more documentation

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        File
            Successfully uploaded file

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.upload()


        asyncio.run(main())
        """
        _response = await self._raw_client.upload(file=file, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EditRunMetrics(UncheckedBaseModel):
    """
    Metrics about the editing process.

    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    processing_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="processingTimeMs")] = pydantic.Field(
        alias="processingTimeMs"
    )
    """
    Total processing time in milliseconds.
    """

    page_count: typing_extensions.Annotated[int, FieldMetadata(alias="pageCount")] = pydantic.Field(alias="pageCount")
    """
    The number of pages in the document.
    """

    field_count: typing_extensions.Annotated[int, FieldMetadata(alias="fieldCount")] = pydantic.Field(
        alias="fieldCount"
    )
    """
    The total number of fields in the schema.
    """

    fields_detected_count: typing_extensions.Annotated[int, FieldMetadata(alias="fieldsDetectedCount")] = (
        pydantic.Field(alias="fieldsDetectedCount")
    )
    """
    The number of fields that were automatically detected.
    """

    fields_annotated_count: typing_extensions.Annotated[int, FieldMetadata(alias="fieldsAnnotatedCount")] = (
        pydantic.Field(alias="fieldsAnnotatedCount")
    )
    """
    The number of fields that were annotated with bounding boxes.
    """

    field_detection_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="fieldDetectionTimeMs")] = (
        pydantic.Field(alias="fieldDetectionTimeMs")
    )
    """
    The time taken to detect fields in the document, in milliseconds.
    """

    field_annotation_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="fieldAnnotationTimeMs")] = (
        pydantic.Field(alias="fieldAnnotationTimeMs")
    )
    """
    The time taken to annotate field positions in the document, in milliseconds.
    """

    field_filling_time_ms: typing_extensions.Annotated[float, FieldMetadata(alias="fieldFillingTimeMs")] = (
        pydantic.Field(alias="fieldFillingTimeMs")
    )
    """
    The time taken to fill the fields in the document, in milliseconds.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class ChunkMetadataPageRangeParams(typing_extensions.TypedDict):
    """
    The page range this chunk covers. Often will just be a partial page, in which cases `start` and `end` will be the same.
    """

    start: int
    """
    The starting page number (inclusive).
    """

    end: int
    """
    The ending page number (inclusive).
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class CitationPageParams(typing_extensions.TypedDict):
    number: float
    """
    Page number where the citation was found. Starts at 1.
    """

    width: typing_extensions.NotRequired[float]
    """
    The width of the page in points.
    """

    height: typing_extensions.NotRequired[float]
    """
    The height of the page in points.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.chunk_type import ChunkType
from .block import BlockParams
from .chunk_metadata import ChunkMetadataParams


class ChunkParams(typing_extensions.TypedDict):
    object: typing.Literal["chunk"]
    """
    The type of object. In this case, it will always be `"chunk"`.
    """

    type: ChunkType
    """
    The type of chunk.
    """

    content: str
    """
    The parsed content of the chunk.
    """

    metadata: ChunkMetadataParams
    """
    Metadata about the chunk.
    """

    blocks: typing.Sequence[BlockParams]
    """
    An array of block objects that make up the chunk. A Block represents a distinct content element within a document, such as a paragraph of text, a heading, a table, or a figure. Blocks are the fundamental units that make up chunks in parsed documents.
    """



# This file was auto-generated by Fern from our API Definition.

import datetime as dt

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.legacy_processor_type import LegacyProcessorType
from .legacy_processor_version import LegacyProcessorVersionParams


class LegacyProcessorParams(typing_extensions.TypedDict):
    object: str
    """
    The type of response. In this case, it will always be `"document_processor"`.
    """

    id: str
    """
    The ID of the processor.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    name: str
    """
    The name of the processor.
    
    Example: `"Invoice Processor"`
    """

    type: LegacyProcessorType
    created_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdAt")]
    """
    The time (in UTC) at which the processor was created. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T15:30:00Z"`
    """

    updated_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="updatedAt")]
    """
    The time (in UTC) at which the processor was last updated. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T16:45:00Z"`
    """

    draft_version: typing_extensions.Annotated[LegacyProcessorVersionParams, FieldMetadata(alias="draftVersion")]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class RunUsageParams(typing_extensions.TypedDict):
    """
    Usage credits consumed by a run.

    **Availability:** This field will not be returned for:
    * Runs created before October 7, 2025
    * Customers on legacy billing systems

    For more details on how credits work, see our [Credits Guide](https://docs.extend.ai/2026-02-09/product/general/how-credits-work).
    """

    credits: float
    """
    The number of credits consumed for this run.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..requests.split_config import SplitConfigParams
from ..types.max_page_size import MaxPageSize
from ..types.next_page_token import NextPageToken
from ..types.processor_run_status import ProcessorRunStatus
from ..types.run_metadata import RunMetadata
from ..types.run_priority import RunPriority
from ..types.run_source import RunSource
from ..types.run_source_id import RunSourceId
from ..types.sort_by import SortBy
from ..types.sort_dir import SortDir
from ..types.split_run import SplitRun
from .raw_client import AsyncRawSplitRunsClient, RawSplitRunsClient
from .requests.split_runs_create_request_file import SplitRunsCreateRequestFileParams
from .requests.split_runs_create_request_splitter import SplitRunsCreateRequestSplitterParams
from .types.split_runs_delete_response import SplitRunsDeleteResponse
from .types.split_runs_list_response import SplitRunsListResponse

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SplitRunsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSplitRunsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSplitRunsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSplitRunsClient
        """
        return self._raw_client

    def list(
        self,
        *,
        status: typing.Optional[ProcessorRunStatus] = None,
        splitter_id: typing.Optional[str] = None,
        source_id: typing.Optional[RunSourceId] = None,
        source: typing.Optional[RunSource] = None,
        file_name_contains: typing.Optional[str] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplitRunsListResponse:
        """
        List all split runs.

        Returns a summary of each run. Use `GET /split_runs/{id}` to retrieve the full object including `output` and `config`.

        Parameters
        ----------
        status : typing.Optional[ProcessorRunStatus]

        splitter_id : typing.Optional[str]
            Filters split runs by the splitter ID. If not provided, all split runs are returned.

            Example: `"spl_BMdfq_yWM3sT-ZzvCnA3f"`

        source_id : typing.Optional[RunSourceId]
            Filters runs by the source ID.

        source : typing.Optional[RunSource]
            Filters runs by the source that created them. If not provided, runs from all sources are returned.

        file_name_contains : typing.Optional[str]
            Filters runs by the name of the file. Only returns runs where the file name contains this string.

            Example: `"invoice"`

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRunsListResponse
            You will get a list of summaries for each split run. These are shortened versions of the full split run object.

            To get the full object, use the [Get Split Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/split/get-split-run) endpoint.

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.split_runs.list(
            next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
        )
        """
        _response = self._raw_client.list(
            status=status,
            splitter_id=splitter_id,
            source_id=source_id,
            source=source,
            file_name_contains=file_name_contains,
            sort_by=sort_by,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        *,
        file: SplitRunsCreateRequestFileParams,
        splitter: typing.Optional[SplitRunsCreateRequestSplitterParams] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        priority: typing.Optional[RunPriority] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplitRun:
        """
        Split a document into multiple parts using an existing splitter or an inline configuration.

        The request returns immediately with a `PROCESSING` status. Use webhooks or poll the [Get Split Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/split/get-split-run) endpoint for results.

        Parameters
        ----------
        file : SplitRunsCreateRequestFileParams
            The file to be split. Files can be provided as a URL or an Extend file ID.

        splitter : typing.Optional[SplitRunsCreateRequestSplitterParams]
            Reference to an existing splitter. One of `splitter` or `config` must be provided.

        config : typing.Optional[SplitConfigParams]
            Inline splitter configuration. One of `splitter` or `config` must be provided.

        priority : typing.Optional[RunPriority]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Split completed successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.split_runs.create(
            file={"url": "url"},
        )
        """
        _response = self._raw_client.create(
            file=file,
            splitter=splitter,
            config=config,
            priority=priority,
            metadata=metadata,
            request_options=request_options,
        )
        return _response.data

    def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> SplitRun:
        """
        Retrieve details about a specific split run, including its status and outputs.

        A common use case for this endpoint is to poll for the status and final output of a split run when using the [Create Split Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/split/create-split-run) endpoint. For instance, if you do not want to not configure webhooks to receive the output via completion/failure events.

        Parameters
        ----------
        id : str
            The unique identifier for this split run.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Successfully retrieved split run

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.split_runs.retrieve(
            id="split_run_id_here",
        )
        """
        _response = self._raw_client.retrieve(id, request_options=request_options)
        return _response.data

    def delete(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> SplitRunsDeleteResponse:
        """
        Delete a split run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the split run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRunsDeleteResponse
            Splitter run deleted successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.split_runs.delete(
            id="id",
        )
        """
        _response = self._raw_client.delete(id, request_options=request_options)
        return _response.data

    def cancel(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> SplitRun:
        """
        Cancel an in-progress split run.

        Note: Only split runs with a status of `"PROCESSING"` can be cancelled. Splitter runs that have already completed, failed, or been cancelled cannot be cancelled again.

        Parameters
        ----------
        id : str
            The ID of the split run to cancel.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Splitter run cancelled successfully

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.split_runs.cancel(
            id="split_run_id_here",
        )
        """
        _response = self._raw_client.cancel(id, request_options=request_options)
        return _response.data


class AsyncSplitRunsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSplitRunsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSplitRunsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSplitRunsClient
        """
        return self._raw_client

    async def list(
        self,
        *,
        status: typing.Optional[ProcessorRunStatus] = None,
        splitter_id: typing.Optional[str] = None,
        source_id: typing.Optional[RunSourceId] = None,
        source: typing.Optional[RunSource] = None,
        file_name_contains: typing.Optional[str] = None,
        sort_by: typing.Optional[SortBy] = None,
        sort_dir: typing.Optional[SortDir] = None,
        next_page_token: typing.Optional[NextPageToken] = None,
        max_page_size: typing.Optional[MaxPageSize] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplitRunsListResponse:
        """
        List all split runs.

        Returns a summary of each run. Use `GET /split_runs/{id}` to retrieve the full object including `output` and `config`.

        Parameters
        ----------
        status : typing.Optional[ProcessorRunStatus]

        splitter_id : typing.Optional[str]
            Filters split runs by the splitter ID. If not provided, all split runs are returned.

            Example: `"spl_BMdfq_yWM3sT-ZzvCnA3f"`

        source_id : typing.Optional[RunSourceId]
            Filters runs by the source ID.

        source : typing.Optional[RunSource]
            Filters runs by the source that created them. If not provided, runs from all sources are returned.

        file_name_contains : typing.Optional[str]
            Filters runs by the name of the file. Only returns runs where the file name contains this string.

            Example: `"invoice"`

        sort_by : typing.Optional[SortBy]

        sort_dir : typing.Optional[SortDir]

        next_page_token : typing.Optional[NextPageToken]

        max_page_size : typing.Optional[MaxPageSize]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRunsListResponse
            You will get a list of summaries for each split run. These are shortened versions of the full split run object.

            To get the full object, use the [Get Split Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/split/get-split-run) endpoint.

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.split_runs.list(
                next_page_token="xK9mLPqRtN3vS8wF5hB2cQ==:zWvUxYjM4nKpL7aDgE9HbTcR2mAyX3/Q+CNkfBSw1dZ=",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            status=status,
            splitter_id=splitter_id,
            source_id=source_id,
            source=source,
            file_name_contains=file_name_contains,
            sort_by=sort_by,
            sort_dir=sort_dir,
            next_page_token=next_page_token,
            max_page_size=max_page_size,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        *,
        file: SplitRunsCreateRequestFileParams,
        splitter: typing.Optional[SplitRunsCreateRequestSplitterParams] = OMIT,
        config: typing.Optional[SplitConfigParams] = OMIT,
        priority: typing.Optional[RunPriority] = OMIT,
        metadata: typing.Optional[RunMetadata] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SplitRun:
        """
        Split a document into multiple parts using an existing splitter or an inline configuration.

        The request returns immediately with a `PROCESSING` status. Use webhooks or poll the [Get Split Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/split/get-split-run) endpoint for results.

        Parameters
        ----------
        file : SplitRunsCreateRequestFileParams
            The file to be split. Files can be provided as a URL or an Extend file ID.

        splitter : typing.Optional[SplitRunsCreateRequestSplitterParams]
            Reference to an existing splitter. One of `splitter` or `config` must be provided.

        config : typing.Optional[SplitConfigParams]
            Inline splitter configuration. One of `splitter` or `config` must be provided.

        priority : typing.Optional[RunPriority]

        metadata : typing.Optional[RunMetadata]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Split completed successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.split_runs.create(
                file={"url": "url"},
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(
            file=file,
            splitter=splitter,
            config=config,
            priority=priority,
            metadata=metadata,
            request_options=request_options,
        )
        return _response.data

    async def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> SplitRun:
        """
        Retrieve details about a specific split run, including its status and outputs.

        A common use case for this endpoint is to poll for the status and final output of a split run when using the [Create Split Run](https://docs.extend.ai/2026-02-09/developers/api-reference/endpoints/split/create-split-run) endpoint. For instance, if you do not want to not configure webhooks to receive the output via completion/failure events.

        Parameters
        ----------
        id : str
            The unique identifier for this split run.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Successfully retrieved split run

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.split_runs.retrieve(
                id="split_run_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(id, request_options=request_options)
        return _response.data

    async def delete(
        self, id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> SplitRunsDeleteResponse:
        """
        Delete a split run and all associated data from Extend. This operation is permanent and cannot be undone.

        This endpoint can be used if you'd like to manage data retention on your own rather than automated data retention policies. Or make one-off deletions for your downstream customers.

        Parameters
        ----------
        id : str
            The ID of the split run.

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRunsDeleteResponse
            Splitter run deleted successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.split_runs.delete(
                id="id",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(id, request_options=request_options)
        return _response.data

    async def cancel(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> SplitRun:
        """
        Cancel an in-progress split run.

        Note: Only split runs with a status of `"PROCESSING"` can be cancelled. Splitter runs that have already completed, failed, or been cancelled cannot be cancelled again.

        Parameters
        ----------
        id : str
            The ID of the split run to cancel.

            Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SplitRun
            Splitter run cancelled successfully

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.split_runs.cancel(
                id="split_run_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.cancel(id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class RuleValidationResultRulesItemFailureReason(enum.StrEnum):
    """
    If the validation rule is not valid, then this describes why the rule failed.
    * `"RULE_FAILED"` - The formula evaluated to `false` or `null`
    * `"PARSE_ERROR"` - The formula could not be parsed
    * `"VALUE_ERROR"` - An error occurred while evaluating the formula
    """

    RULE_FAILED = "RULE_FAILED"
    PARSE_ERROR = "PARSE_ERROR"
    VALUE_ERROR = "VALUE_ERROR"
    _UNKNOWN = "__RULEVALIDATIONRESULTRULESITEMFAILUREREASON_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "RuleValidationResultRulesItemFailureReason":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        rule_failed: typing.Callable[[], T_Result],
        parse_error: typing.Callable[[], T_Result],
        value_error: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is RuleValidationResultRulesItemFailureReason.RULE_FAILED:
            return rule_failed()
        if self is RuleValidationResultRulesItemFailureReason.PARSE_ERROR:
            return parse_error()
        if self is RuleValidationResultRulesItemFailureReason.VALUE_ERROR:
            return value_error()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

"""
Provides a StrEnum base class that works across Python versions.

For Python >= 3.11, this re-exports the standard library enum.StrEnum.
For older Python versions, this defines a compatible StrEnum using the
(str, Enum) mixin pattern so that generated SDKs can use a single base
class in all supported Python versions.
"""

import enum
import sys

if sys.version_info >= (3, 11):
    from enum import StrEnum
else:

    class StrEnum(str, enum.Enum):
        pass



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .rule_validation_result_rules_item import RuleValidationResultRulesItem


class RuleValidationResult(UncheckedBaseModel):
    """
    The result of a rule validation step.
    """

    rules: typing.List[RuleValidationResultRulesItem] = pydantic.Field()
    """
    The list of validation rules and their results.
    """

    all_passed: typing_extensions.Annotated[bool, FieldMetadata(alias="allPassed")] = pydantic.Field(alias="allPassed")
    """
    Indicates whether all validation rules passed.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .processor_version_create_request_config import (
        ProcessorVersionCreateRequestConfig,
        ProcessorVersionCreateRequestConfig_Classify,
        ProcessorVersionCreateRequestConfig_Extract,
        ProcessorVersionCreateRequestConfig_Splitter,
    )
    from .processor_version_create_request_release_type import ProcessorVersionCreateRequestReleaseType
    from .processor_version_create_response import ProcessorVersionCreateResponse
    from .processor_version_get_response import ProcessorVersionGetResponse
    from .processor_version_list_response import ProcessorVersionListResponse
_dynamic_imports: typing.Dict[str, str] = {
    "ProcessorVersionCreateRequestConfig": ".processor_version_create_request_config",
    "ProcessorVersionCreateRequestConfig_Classify": ".processor_version_create_request_config",
    "ProcessorVersionCreateRequestConfig_Extract": ".processor_version_create_request_config",
    "ProcessorVersionCreateRequestConfig_Splitter": ".processor_version_create_request_config",
    "ProcessorVersionCreateRequestReleaseType": ".processor_version_create_request_release_type",
    "ProcessorVersionCreateResponse": ".processor_version_create_response",
    "ProcessorVersionGetResponse": ".processor_version_get_response",
    "ProcessorVersionListResponse": ".processor_version_list_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionGetResponse",
    "ProcessorVersionListResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ParseRequestResponseType(enum.StrEnum):
    JSON = "json"
    URL = "url"
    _UNKNOWN = "__PARSEREQUESTRESPONSETYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ParseRequestResponseType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        json: typing.Callable[[], T_Result],
        url: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ParseRequestResponseType.JSON:
            return json()
        if self is ParseRequestResponseType.URL:
            return url()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..types.json_object import JsonObject
from .legacy_json_output_metadata_value import LegacyJsonOutputMetadataValueParams


class LegacyJsonOutputParams(typing_extensions.TypedDict):
    value: JsonObject
    """
    The extracted values conforming to the schema defined in the processor config
    """

    metadata: typing.Dict[str, LegacyJsonOutputMetadataValueParams]
    """
    Metadata about the extracted fields
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.legacy_classification_config_base_processor import LegacyClassificationConfigBaseProcessor
from .legacy_classification import LegacyClassificationParams
from .legacy_classification_advanced_options import LegacyClassificationAdvancedOptionsParams
from .parse_config import ParseConfigParams


class LegacyClassificationConfigParams(typing_extensions.TypedDict):
    base_processor: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyClassificationConfigBaseProcessor, FieldMetadata(alias="baseProcessor")]
    ]
    """
    The base processor to use. For classifiers, this must be either `"classification_performance"` or `"classification_light"`. See [Classification Changelog](/changelog/classification/classification-performance) for more details.
    """

    base_version: typing_extensions.NotRequired[typing_extensions.Annotated[str, FieldMetadata(alias="baseVersion")]]
    """
    The version of the `"classification_performance"` or `"classification_light"` processor to use. If this is provided, the `baseProcessor` must also be provided. See [Classification Changelog](/changelog/classification/classification-performance) for more details.
    """

    classifications: typing.Sequence[LegacyClassificationParams]
    """
    Array of possible classifications for the document.
    """

    classification_rules: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="classificationRules")]
    ]
    """
    Custom rules to guide the classification process in natural language.
    """

    advanced_options: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyClassificationAdvancedOptionsParams, FieldMetadata(alias="advancedOptions")]
    ]
    """
    Advanced configuration options.
    """

    parser: typing_extensions.NotRequired[ParseConfigParams]
    """
    Configuration options for the parsing process.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.evaluation_set_run import EvaluationSetRun
from .raw_client import AsyncRawEvaluationSetRunsClient, RawEvaluationSetRunsClient


class EvaluationSetRunsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawEvaluationSetRunsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawEvaluationSetRunsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawEvaluationSetRunsClient
        """
        return self._raw_client

    def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EvaluationSetRun:
        """
        Get details of an evaluation set run.

        Parameters
        ----------
        id : str
            The ID of the evaluation set run.

            Example: `"evr_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetRun
            Successfully retrieved evaluation set run

        Examples
        --------
        from extend_ai import Extend

        client = Extend(
            token="YOUR_TOKEN",
        )
        client.evaluation_set_runs.retrieve(
            id="evaluation_set_run_id_here",
        )
        """
        _response = self._raw_client.retrieve(id, request_options=request_options)
        return _response.data


class AsyncEvaluationSetRunsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawEvaluationSetRunsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawEvaluationSetRunsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawEvaluationSetRunsClient
        """
        return self._raw_client

    async def retrieve(self, id: str, *, request_options: typing.Optional[RequestOptions] = None) -> EvaluationSetRun:
        """
        Get details of an evaluation set run.

        Parameters
        ----------
        id : str
            The ID of the evaluation set run.

            Example: `"evr_Xj8mK2pL9nR4vT7qY5wZ"`

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        EvaluationSetRun
            Successfully retrieved evaluation set run

        Examples
        --------
        import asyncio

        from extend_ai import AsyncExtend

        client = AsyncExtend(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.evaluation_set_runs.retrieve(
                id="evaluation_set_run_id_here",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.retrieve(id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_provided_extraction_field_result import LegacyProvidedExtractionFieldResult

LegacyProvidedFieldsArrayOutput = typing.Dict[str, LegacyProvidedExtractionFieldResult]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .legacy_classification_advanced_options_context import LegacyClassificationAdvancedOptionsContext
from .page_ranges import PageRanges


class LegacyClassificationAdvancedOptions(UncheckedBaseModel):
    context: typing.Optional[LegacyClassificationAdvancedOptionsContext] = pydantic.Field(default=None)
    """
    The context to use for classification.
    """

    advanced_multimodal_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="advancedMultimodalEnabled")
    ] = pydantic.Field(alias="advancedMultimodalEnabled", default=None)
    """
    Enable advanced multimodal processing for better handling of visual elements during classification.
    """

    fixed_page_limit: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="fixedPageLimit")] = (
        pydantic.Field(alias="fixedPageLimit", default=None)
    )
    """
    Limit processing to a specific number of pages from the beginning of the document. See [Page Ranges](/product/page-ranges).
    """

    page_ranges: typing_extensions.Annotated[typing.Optional[PageRanges], FieldMetadata(alias="pageRanges")] = (
        pydantic.Field(alias="pageRanges", default=None)
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .parse_config_advanced_options import ParseConfigAdvancedOptions
from .parse_config_block_options import ParseConfigBlockOptions
from .parse_config_chunking_strategy import ParseConfigChunkingStrategy
from .parse_config_engine import ParseConfigEngine
from .parse_config_target import ParseConfigTarget


class ParseConfig(UncheckedBaseModel):
    """
    Configuration options for the parsing process. Defaults depend on the selected parser engine and version.
    """

    target: typing.Optional[ParseConfigTarget] = pydantic.Field(default=None)
    """
    The target format for the parsed content.
    
    Supported values:
    
    * `markdown`: True markdown with logical reading order (headings, lists, tables, checkboxes). Best default for LLMs/RAG and enables section-based chunking.
    * `spatial`: Layout/position-preserving text that uses markdown elements for block types but is not strictly markdown due to whitespace/tabs used to maintain placement. Only page-based chunking is supported.
    
    Guidance:
    
    * Prefer `markdown` for most documents, multi-column reading order, and retrieval use cases
    * Prefer `spatial` for messy/scanned/handwritten or skewed documents, when you need near 1:1 layout fidelity, or for BOL-like logistics docs
    
    See “Markdown vs Spatial” in the [Parse guide](https://docs.extend.ai/2026-02-09/developers/guides/parse#markdown-vs-spatial) for details.
    """

    chunking_strategy: typing_extensions.Annotated[
        typing.Optional[ParseConfigChunkingStrategy], FieldMetadata(alias="chunkingStrategy")
    ] = pydantic.Field(alias="chunkingStrategy", default=None)
    """
    Strategy for dividing the document into chunks.
    """

    engine: typing.Optional[ParseConfigEngine] = pydantic.Field(default=None)
    """
    The parsing engine to use. Supported values:
    * `parse_performance`: Full-featured parsing engine with highest accuracy (default)
    * `parse_light`: Lightweight parsing engine optimized for speed. This does not have robust layout support and does not support markdown layout target.
    """

    block_options: typing_extensions.Annotated[
        typing.Optional[ParseConfigBlockOptions], FieldMetadata(alias="blockOptions")
    ] = pydantic.Field(alias="blockOptions", default=None)
    """
    Options for controlling how different block types are processed.
    """

    advanced_options: typing_extensions.Annotated[
        typing.Optional[ParseConfigAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata


class TableDetailsParams(typing_extensions.TypedDict):
    """
    Details for table blocks
    """

    type: typing.Literal["table_details"]
    """
    Indicates this is a table details object
    """

    row_count: typing_extensions.Annotated[int, FieldMetadata(alias="rowCount")]
    """
    The number of rows in the table
    """

    column_count: typing_extensions.Annotated[int, FieldMetadata(alias="columnCount")]
    """
    The number of columns in the table
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from .external_data_validation_result import ExternalDataValidationResultParams
from .external_data_validation_step_run_step import ExternalDataValidationStepRunStepParams
from .step_run_base import StepRunBaseParams


class ExternalDataValidationStepRunParams(StepRunBaseParams):
    step: ExternalDataValidationStepRunStepParams
    result: typing.Optional[ExternalDataValidationResultParams]
    """
    The result of this external data validation step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """
